==> asteroid-launcher-2.0.0.tar.gz: asteroid-launcher-2.0.0/i18n/asteroid-launcher.es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name></name>
    <message id="id-btagent-authorize">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="158"/>
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="170"/>
        <source>Authorize:</source>
        <translation>Autorizar:</translation>
    </message>
    <message id="id-btagent-confirm">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="182"/>
        <source>Confirm:</source>
        <translation>Confirmar:</translation>
    </message>
    <message id="id-btagent-passkey">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="194"/>
        <source>Pass Key:</source>
        <translation>Clave de paso:</translation>
    </message>
    <message id="id-btagent-enterkey">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="210"/>
        <source>Enter Key</source>
        <translation>Introducir clave</translation>
    </message>
    <message id="id-btagent-pincode">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="218"/>
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="230"/>
        <source>PIN Code:</source>
        <translation>Código PIN:</translation>
    </message>
    <message id="id-btagent-enter-pincode">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="235"/>
        <source>Enter PIN Code</source>
        <translation>Introducir código PIN</translation>
    </message>
    <message id="id-snooze">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="115"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="157"/>
        <source>Snooze</source>
        <translation>Posponer</translation>
    </message>
    <message id="id-dismiss-all">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="123"/>
        <source>Dismiss all</source>
        <translation>Descartar todo</translation>
    </message>
    <message id="id-dismiss">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="138"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="161"/>
        <source>Dismiss</source>
        <translation>Descartar</translation>
    </message>
    <message id="id-now">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="58"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="63"/>
        <source>Now</source>
        <translation>Ahora</translation>
    </message>
    <message id="id-minute-abbrev">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="63"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="168"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="179"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="68"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message id="id-hour-abbrev">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="68"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="190"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="201"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="73"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message id="id-day-abbrev">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="72"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="77"/>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message id="id-no-notifications">
        <location filename="../src/qml/notifications/NotificationsPanel.qml" line="156"/>
        <source>No notifications</source>
        <translation>No hay notificaciones</translation>
    </message>
    <message id="id-today">
        <location filename="../src/qml/today/Today.qml" line="136"/>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message id="id-no-events-today">
        <location filename="../src/qml/today/Today.qml" line="207"/>
        <source>No events today</source>
        <translation>No hay eventos hoy</translation>
    </message>
    <message id="id-date-page">
        <location filename="../src/qml/firstrun/FirstRunConfig.qml" line="201"/>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message id="id-add-alarm">
        <location filename="../src/qml/firstrun/FakeAlarmclock.qml" line="85"/>
        <source>Add an alarm</source>
        <translation>Añadir una alarma</translation>
    </message>
    <message id="id-time">
        <location filename="../src/qml/firstrun/FakeAlarmclock.qml" line="125"/>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message id="id-language-page">
        <location filename="../src/qml/firstrun/FirstRunConfig.qml" line="171"/>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message id="id-time-page">
        <location filename="../src/qml/firstrun/FirstRunConfig.qml" line="190"/>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message id="id-tutorial-welcome-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="60"/>
        <source>Welcome.</source>
        <translation>Bienvenido.</translation>
    </message>
    <message id="id-tutorial-welcome-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="62"/>
        <source>This is AsteroidOS.</source>
        <translation>Esto es AsteroidOS.</translation>
    </message>
    <message id="id-tutorial-indicators-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="73"/>
        <source>Indicators</source>
        <translation>Indicadores</translation>
    </message>
    <message id="id-tutorial-indicators-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="75"/>
        <source>show you possible gestures.</source>
        <translation>Muestra los gestos posibles.</translation>
    </message>
    <message id="id-tutorial-notifications-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="93"/>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message id="id-tutorial-notifications-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="95"/>
        <source>can be accessed on the left.</source>
        <translation>se puede acceder desde la izquierda.</translation>
    </message>
    <message id="id-tutorial-today-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="122"/>
        <source>Today&apos;s Events</source>
        <translation>Eventos de hoy</translation>
    </message>
    <message id="id-tutorial-today-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="124"/>
        <source>are on the right.</source>
        <translation>están a la derecha.</translation>
    </message>
    <message id="id-tutorial-quicksettings-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="171"/>
        <source>Quick Settings</source>
        <translation>Ajustes rápidos</translation>
    </message>
    <message id="id-tutorial-quicksettings-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="173"/>
        <source>are up here.</source>
        <translation>están aquí arriba.</translation>
    </message>
    <message id="id-tutorial-applications-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="220"/>
        <source>Apps</source>
        <translation>Aplicaciones</translation>
    </message>
    <message id="id-tutorial-applications-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="222"/>
        <source>are down there.</source>
        <translation>están aquí abajo.</translation>
    </message>
    <message id="id-tutorial-startapp-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="269"/>
        <source>Start an app</source>
        <translation>Iniciar una aplicación</translation>
    </message>
    <message id="id-tutorial-startapp-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="271"/>
        <source>by pressing its icon.</source>
        <translation>presionando su icono.</translation>
    </message>
    <message id="id-tutorial-leaveapp-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="334"/>
        <source>Leave an app</source>
        <translation>Salir de una aplicación</translation>
    </message>
    <message id="id-tutorial-leaveapp-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="336"/>
        <source>following a rightward gesture.</source>
        <translation>deslizando hacia la derecha.</translation>
    </message>
    <message id="id-tutorial-enjoy-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="400"/>
        <source>Enjoy!</source>
        <translation>¡Disfruta!</translation>
    </message>
</context>
</TS>

==> asteroid-launcher-2.1.0.tar.gz: asteroid-launcher-2.1.0/i18n/asteroid-launcher.es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name></name>
    <message id="id-btagent-authorize">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="158"/>
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="170"/>
        <source>Authorize:</source>
        <translation>Autorizar:</translation>
    </message>
    <message id="id-btagent-confirm">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="182"/>
        <source>Confirm:</source>
        <translation>Confirmar:</translation>
    </message>
    <message id="id-btagent-passkey">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="194"/>
        <source>Pass Key:</source>
        <translation>Clave de paso:</translation>
    </message>
    <message id="id-btagent-enterkey">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="210"/>
        <source>Enter Key</source>
        <translation>Introducir clave</translation>
    </message>
    <message id="id-btagent-pincode">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="218"/>
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="230"/>
        <source>PIN Code:</source>
        <translation>Código PIN:</translation>
    </message>
    <message id="id-btagent-enter-pincode">
        <location filename="../src/qml/misc/BluetoothAgent.qml" line="235"/>
        <source>Enter PIN Code</source>
        <translation>Introducir código PIN</translation>
    </message>
    <message id="id-snooze">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="115"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="157"/>
        <source>Snooze</source>
        <translation>Posponer</translation>
    </message>
    <message id="id-dismiss-all">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="123"/>
        <source>Dismiss all</source>
        <translation>Descartar todo</translation>
    </message>
    <message id="id-dismiss">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="138"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="161"/>
        <source>Dismiss</source>
        <translation>Descartar</translation>
    </message>
    <message id="id-now">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="58"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="63"/>
        <source>Now</source>
        <translation>Ahora</translation>
    </message>
    <message id="id-minute-abbrev">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="63"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="168"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="179"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="68"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message id="id-hour-abbrev">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="68"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="190"/>
        <location filename="../src/qml/notifications/NotificationActions.qml" line="201"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="73"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message id="id-day-abbrev">
        <location filename="../src/qml/notifications/NotificationActions.qml" line="72"/>
        <location filename="../src/qml/notifications/NotificationView.qml" line="77"/>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message id="id-no-notifications">
        <location filename="../src/qml/notifications/NotificationsPanel.qml" line="156"/>
        <source>No notifications</source>
        <translation>Sin notificaciones</translation>
    </message>
    <message id="id-today">
        <location filename="../src/qml/today/Today.qml" line="136"/>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message id="id-no-events-today">
        <location filename="../src/qml/today/Today.qml" line="207"/>
        <source>No events today</source>
        <translation>No hay eventos hoy</translation>
    </message>
    <message id="id-date-page">
        <location filename="../src/qml/firstrun/FirstRunConfig.qml" line="201"/>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message id="id-add-alarm">
        <location filename="../src/qml/firstrun/FakeAlarmclock.qml" line="85"/>
        <source>Add an alarm</source>
        <translation>Añadir una alarma</translation>
    </message>
    <message id="id-time">
        <location filename="../src/qml/firstrun/FakeAlarmclock.qml" line="125"/>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message id="id-language-page">
        <location filename="../src/qml/firstrun/FirstRunConfig.qml" line="171"/>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message id="id-time-page">
        <location filename="../src/qml/firstrun/FirstRunConfig.qml" line="190"/>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message id="id-tutorial-welcome-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="60"/>
        <source>Welcome.</source>
        <translation>Bienvenido.</translation>
    </message>
    <message id="id-tutorial-welcome-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="62"/>
        <source>This is AsteroidOS.</source>
        <translation>Esto es AsteroidOS.</translation>
    </message>
    <message id="id-tutorial-indicators-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="73"/>
        <source>Indicators</source>
        <translation>Indicadores</translation>
    </message>
    <message id="id-tutorial-indicators-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="75"/>
        <source>show you possible gestures.</source>
        <translation>Muestra los gestos posibles.</translation>
    </message>
    <message id="id-tutorial-notifications-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="93"/>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message id="id-tutorial-notifications-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="95"/>
        <source>can be accessed on the left.</source>
        <translation>se puede acceder desde la izquierda.</translation>
    </message>
    <message id="id-tutorial-today-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="122"/>
        <source>Today&apos;s Events</source>
        <translation>Eventos de hoy</translation>
    </message>
    <message id="id-tutorial-today-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="124"/>
        <source>are on the right.</source>
        <translation>están a la derecha.</translation>
    </message>
    <message id="id-tutorial-quicksettings-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="171"/>
        <source>Quick Settings</source>
        <translation>Ajustes rápidos</translation>
    </message>
    <message id="id-tutorial-quicksettings-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="173"/>
        <source>are up here.</source>
        <translation>están aquí arriba.</translation>
    </message>
    <message id="id-tutorial-applications-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="220"/>
        <source>Apps</source>
        <translation>Aplicaciones</translation>
    </message>
    <message id="id-tutorial-applications-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="222"/>
        <source>are down there.</source>
        <translation>están aquí abajo.</translation>
    </message>
    <message id="id-tutorial-startapp-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="269"/>
        <source>Start an app</source>
        <translation>Iniciar una aplicación</translation>
    </message>
    <message id="id-tutorial-startapp-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="271"/>
        <source>by pressing its icon.</source>
        <translation>presionando su icono.</translation>
    </message>
    <message id="id-tutorial-leaveapp-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="334"/>
        <source>Leave an app</source>
        <translation>Salir de una aplicación</translation>
    </message>
    <message id="id-tutorial-leaveapp-subtitle">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="336"/>
        <source>following a rightward gesture.</source>
        <translation>deslizando hacia la derecha.</translation>
    </message>
    <message id="id-tutorial-enjoy-title">
        <location filename="../src/qml/firstrun/Tutorial.qml" line="400"/>
        <source>Enjoy!</source>
        <translation>¡Disfruta!</translation>
    </message>
</context>
</TS>
